@@ -1,7 +1,8 @@
 import copy
 
 import django
-from django.core.exceptions import ImproperlyConfigured, Resolver404
+from django.core.exceptions import ImproperlyConfigured
+from django.urls import Resolver404
 from .utils import get_callable, parse_url, path_startswith
 
 if django.VERSION >= (1, 10):  # pragma: no cover
